@@ -5,7 +5,7 @@ package Dist::Zilla::PluginBundle::NIGELM;
 use strict;
 use warnings;
 
-our $VERSION = '0.15'; # VERSION
+our $VERSION = '0.16'; # VERSION
 our $AUTHORITY = 'cpan:NIGELM'; # AUTHORITY
 
 use Moose 1.00;
@@ -123,16 +123,16 @@ has is_task => (
     builder => '_build_is_task',
 );
 
-method _build_is_task() {
+method _build_is_task () {
     return $self->dist =~ /^Task-/ ? 1 : 0;
-    }
+}
 
 
-    has weaver_config_plugin => (
+has weaver_config_plugin => (
     is      => 'ro',
     isa     => Str,
     default => '@MARCEL',
-    );
+);
 
 
 has bugtracker_url => (
@@ -143,27 +143,27 @@ has bugtracker_url => (
     handles => { bugtracker_url => 'as_string', },
 );
 
-method _build_bugtracker_url() {
+method _build_bugtracker_url () {
     return sprintf $self->_rt_uri_pattern, $self->dist;
-    }
+}
 
 
-    has bugtracker_email => (
+has bugtracker_email => (
     is      => 'ro',
     isa     => EmailAddress,
     lazy    => 1,
     builder => '_build_bugtracker_email',
-    );
+);
 
-method _build_bugtracker_email() {
+method _build_bugtracker_email () {
     return sprintf 'bug-%s@rt.cpan.org', $self->dist;
-    }
+}
 
-    has _rt_uri_pattern => (
+has _rt_uri_pattern => (
     is      => 'ro',
     isa     => Str,
     default => 'http://rt.cpan.org/Public/Dist/Display.html?Name=%s',
-    );
+);
 
 
 has disable_pod_coverage_tests => (
@@ -209,15 +209,15 @@ has homepage_url => (
     handles => { homepage_url => 'as_string', },
 );
 
-method _build_homepage_url() {
+method _build_homepage_url () {
     return sprintf $self->_cpansearch_pattern, $self->dist;
-    }
+}
 
-    has _cpansearch_pattern => (
+has _cpansearch_pattern => (
     is      => 'ro',
     isa     => Str,
     default => 'https://metacpan.org/release/%s',
-    );
+);
 
 
 has repository_at => (
@@ -280,14 +280,14 @@ coerce $map_tc, from Map [
     };
     };
 
-method _build__repository_host_map() {
-    my $github_pattern         = sub { sprintf 'git://github.com/%s/%%s.git', $self->github_user };
-        my $github_web_pattern = sub { sprintf 'http://github.com/%s/%%s',    $self->github_user };
-        my $scsys_web_pattern_proto = sub {
+method _build__repository_host_map () {
+    my $github_pattern     = sub { sprintf 'git://github.com/%s/%%s.git', $self->github_user };
+    my $github_web_pattern = sub { sprintf 'http://github.com/%s/%%s',    $self->github_user };
+    my $scsys_web_pattern_proto = sub {
         return sprintf 'http://git.shadowcat.co.uk/gitweb/gitweb.cgi?p=%s/%%s.git;a=summary', $_[0];
-        };
+    };
 
-        return {
+    return {
         github => {
             pattern     => $github_pattern,
             web_pattern => $github_web_pattern,
@@ -314,24 +314,24 @@ method _build__repository_host_map() {
                     )
                 } qw(catagits p5sagit dbsrgits)
         ),
-        };
-    }
+    };
+}
 
-    method _build_repository_url() {
+method _build_repository_url () {
     return $self->_resolve_repository_with( $self->repository_at, 'pattern' )
         if $self->has_repository_at;
     confess "Cannot determine repository url without repository_at. "
         . "Please provide either repository_at or repository.";
-    }
+}
 
-    has _repository_host_map => (
+has _repository_host_map => (
     traits  => [qw(Hash)],
     isa     => $map_tc,
     coerce  => 1,
     lazy    => 1,
     builder => '_build__repository_host_map',
     handles => { _repository_data_for => 'get', },
-    );
+);
 
 
 has repository_web => (
@@ -342,49 +342,50 @@ has repository_web => (
     handles => { repository_web => 'as_string', },
 );
 
-method _build_repository_web() {
+method _build_repository_web () {
     return $self->_resolve_repository_with( $self->repository_at, 'web_pattern' )
         if $self->has_repository_at;
     confess "Cannot determine repository web url without repository_at. "
         . "Please provide either repository_at or repository_web.";
-    }
+}
 
-    method _resolve_repository_with( $service, $thing ) {
-    my $dist     = $self->dist;
-        my $data = $self->_repository_data_for($service);
-        confess "unknown repository service $service" unless $data;
+method _resolve_repository_with ( $service, $thing ) {
+    my $dist = $self->dist;
+    my $data = $self->_repository_data_for($service);
+    confess "unknown repository service $service" unless $data;
     return sprintf $data->{$thing}->(),
-    (   exists $data->{mangle}
+        (
+        exists $data->{mangle}
         ? $data->{mangle}->($dist)
         : $dist
-    );
-    }
+        );
+}
 
 
-    has repository_type => (
+has repository_type => (
     is      => 'ro',
     isa     => Str,
     lazy    => 1,
     builder => '_build_repository_type',
-    );
+);
 
-method _build_repository_type() {
+method _build_repository_type () {
     my $data = $self->_repository_data_for( $self->repository_at );
-        return $data->{type} if exists $data->{type};
+    return $data->{type} if exists $data->{type};
 
     for my $vcs (qw(git svn)) {
         return $vcs if $self->repository_scheme eq $vcs;
     }
 
     confess "Unable to guess repository type based on the repository url. " . "Please provide repository_type.";
-    }
+}
 
 
-    has github_user => (
+has github_user => (
     is      => 'ro',
     isa     => Str,
     default => 'nigelm',
-    );
+);
 
 
 has tag_format => (
@@ -406,18 +407,18 @@ has version_regexp => (
     builder => '_build_version_regexp',
 );
 
-method _build_version_regexp() {
+method _build_version_regexp () {
     my $version_regexp = $self->tag_format;
-        $version_regexp =~ s/\%v/\(\\d+\(\?:\\.\\d+\)\+\)/;
-        $version_regexp =~ s/\%t/\(\?:\[-_\]\.+\)\?/;
-        return sprintf( '^%s$', $version_regexp );
-    }
+    $version_regexp =~ s/\%v/\(\\d+\(\?:\\.\\d+\)\+\)/;
+    $version_regexp =~ s/\%t/\(\?:\[-_\]\.+\)\?/;
+    return sprintf( '^%s$', $version_regexp );
+}
 
-    has git_autoversion => (
+has git_autoversion => (
     is      => 'ro',
     isa     => 'Bool',
     default => 1,
-    );
+);
 
 
 # git allow dirty references
@@ -442,7 +443,7 @@ override BUILDARGS => sub {
     return { %{ $args->{payload} }, %{$args} };
 };
 
-method configure() {
+method configure () {
 
     # Build a list of all the plugins we want...
     my @wanted = (
@@ -470,7 +471,7 @@ method configure() {
             $self->disable_pod_coverage_tests ? () : [ KwaliteeTests => {} ]
         ),
         [ 'Test::Portability'    => {} ],
-        [ 'SynopsisTests'        => {} ],
+        [ 'Test::Synopsis'       => {} ],
         [ 'Test::MinimumVersion' => {} ],
         [ HasVersionTests        => {} ],
         [ 'Test::DistManifest'   => {} ],
@@ -557,10 +558,10 @@ method configure() {
         ),
     );
 
-        $self->add_plugins(@wanted);
-    }
+    $self->add_plugins(@wanted);
+}
 
-    with 'Dist::Zilla::Role::PluginBundle::Easy';
+with 'Dist::Zilla::Role::PluginBundle::Easy';
 
 __PACKAGE__->meta->make_immutable;
 
@@ -582,7 +583,7 @@ Dist::Zilla::PluginBundle::NIGELM - Build your distributions like I do
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
